<?php

namespace Litecms\Campaign\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Campaign\Models\Campaign;


class CampaignAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Campaign $campaign, array $request = [])
    {
        $this->model = $campaign;

        $function = Str::camel($action);
        event('litecms.campaign.campaign.action.' . $action . 'ing', [$campaign]);
        $data =  $this->$function($campaign, $request);
        event('litecms.campaign.campaign.action.' . $action . 'ed', [$campaign]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Campaign $campaign, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $campaign = $campaign->create($attributes);
        return $campaign;
    }

    public function update(Campaign $campaign, array $request)
    {
        $attributes = $request;
        $campaign->update($attributes);
        return $campaign;
    }

    public function delete(Campaign $campaign, array $request)
    {
        $campaign->delete();
        return $campaign;
    }

    public function copy(Campaign $campaign, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $campaign = $campaign->replicate();
            $campaign->created_at = Carbon::now();
            $campaign->save();
            return $campaign;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $campaign->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $campaign;
    }


}
