<?php

namespace Litecms\Campaign\Actions;

use Illuminate\Support\Str;
use Litecms\Campaign\Models\Campaign;
use Litecms\Campaign\Scopes\CampaignResourceScope;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Database\RequestScope;

class CampaignActions
{
    use AsAction;
    use LogsActions;
    
    private $model;

    public function handle(string $action, array $request)
    {
        $this->model = app(Campaign::class);

        $function = Str::camel($action);

        event('litecms.campaign.campaign.action.' . $action . 'ing', [$request]);
        $data = $this->$function($request);
        event('litecms.campaign.campaign.action.' . $action . 'ed', [$data]);

        $this->logsAction();
        return $data;

    }

    public function paginate(array $request)
    {
        $pageLimit = isset($request['pageLimit']) ?: config('database.pagination.limit');
        $campaign = $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new CampaignResourceScope())
            ->paginate($pageLimit);

        return $campaign;
    }

    public function simplePaginate(array $request)
    {
        $pageLimit = isset($request['pageLimit']) ?: config('database.pagination.limit');
        $campaign = $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new CampaignResourceScope())
            ->simplePaginate($pageLimit);

        return $campaign;
    }

    function empty(array $request) {
        return $this->model->forceDelete();
    }

    function restore(array $request) {
        return $this->model->restore();
    }

    public function delete(array $request)
    {
        $ids = $request['ids'];
        $ids = collect($ids)->map(function ($id) {
            return hashids_decode($id);
        });
        return $this->model->whereIn('id', $ids)->delete();
    }
}
