<?php

namespace Litecms\Campaign\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Campaign\Http\Requests\CampaignActionsRequest;
use Litecms\Campaign\Models\CampaignActions;

/**
 * Admin web controller class.
 */
class CampaignActionsController extends BaseController
{

    /**
     * Action controller function for campaign.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CampaignActionsRequest $request, $action)
    {
        try {
            $campaign = CampaignActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('campaign::campaign.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('campaign/campaign/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('campaign/campaign/' . $action))
                ->redirect();
        }
    }
}
