<?php

namespace Litecms\Campaign\Http\Controllers;

use Exception;
use Litecms\Campaign\Actions\CampaignWorkflow;
use Litecms\Campaign\Http\Requests\CampaignWorkflowRequest;
use Litecms\Campaign\Http\Resources\CampaignResource;
use Litecms\Campaign\Models\Campaign;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class CampaignWorkflowController extends BaseController
{
    /**
     * Action controller function for campaign.
     *
     * @param Model $campaign
     * @param action next action for the campaign.
     *
     * @return Response
     */
    public function __invoke(CampaignWorkflowRequest $request, Campaign $campaign, $trasition)
    {
        try {
            $campaign = CampaignWorkflow::run($request, $campaign, $trasition);
            $data = new CampaignResource($campaign);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('campaign::campaign.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('campaign/campaign/' . $campaign->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('campaign/campaign/' . $campaign->getRouteKey()))
                ->redirect();
        }
    }
}
