<?php
namespace Litecms\Campaign\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Campaign\Events\CampaignAction as CampaignActionEvent;
use Litecms\Campaign\Models\Campaign;

class CampaignAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $campaign;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param CampaignActionEvent $campaign
     * @param string $action
     */
    public function __construct(CampaignActionEvent $campaign, string $action)
    {
        $this->action = $action;
        $this->campaign = $campaign;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Campaign Approved - ' . config('app.name'))
            ->view('campaign::campaign.email.action', ['data' => $this->campaign]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
